@@ -797,7 +797,7 @@ def get_last_commit_sha_by_branch(git_host, git_token, git_project_id, git_branc
     if res.status_code == 200:
         return json.loads(res.content)['id']
     else:
-        raise Exception('commit sha get failure %s' % url)
+        raise Exception(res)
 
 
 def get_gitlab_last_pipeline_id_by_branch(git_host, git_token, git_project_id, git_branch):
